"""Data models for the application, including supported languages."""

SUPPORTED_LANGUAGES = {
    ".py": "Python",
    ".java": "Java",
    ".js": "JavaScript",
    ".jsx": "JavaScript",
    ".ts": "TypeScript",
    ".tsx": "TypeScript",
    ".cpp": "C++",
    ".hpp": "C++",
    ".h": "C++",
    ".cs": "C#",
    ".rb": "Ruby",
    ".go": "Go",
    ".php": "PHP",
    ".txt": "Text",
    ".md": "Markdown",
    ".sh": "Shell",
    ".yml": "YAML",
    ".yaml": "YAML",
    ".json": "JSON",
    ".html": "HTML",
    ".css": "CSS",
    ".scss": "SCSS",
    ".less": "LESS",
    ".sql": "SQL",
    ".r": "R",
    ".kt": "Kotlin",
    ".swift": "Swift",
    ".pl": "Perl",
    ".asm": "Assembly",
    ".clj": "Clojure",
    ".groovy": "Groovy",
    ".lua": "Lua",
    ".pas": "Pascal",
    ".scala": "Scala",
    ".tsv": "TSV",
    ".csv": "CSV",
    ".xml": "XML",
    ".ini": "INI",
    ".cfg": "Config",
    ".conf": "Config",
    ".env": "Config",
    ".envrc": "Config",
    ".tf": "Terraform",
    ".tfvars": "Terraform",
    ".tfstate": "Terraform",
    ".tfstate.backup": "Terraform",
    ".hcl": "Terraform",
    ".dockerfile": "Docker",
    ".tfignore": "Terraform",
    ".gitignore": "Git",
    ".gitattributes": "Git",
    ".db": "Database",
    ".sqlite": "Database",
    ".db3": "Database",
    ".dbf": "Database",
    ".dbx": "Database",
    ".mdb": "Database",
    ".accdb": "Database",
    ".frm": "Database",
    ".sqlitedb": "Database",
    ".png": "Image",
    ".jpg": "Image",
    ".jpeg": "Image",
    ".gif": "Image",
    ".svg": "Image",
    ".bmp": "Image",
    ".ico": "Image",
    ".tif": "Image",
    ".tiff": "Image",
    ".webp": "Image",
    ".heic": "Image",
    ".heif": "Image",
    ".pdf": "PDF",
    ".doc": "Document",
    ".docx": "Document",
    ".ppt": "PowerPointPresentation",
    ".wav": "Audio",
    ".mp3": "Audio",
    ".mp4": "Video",
    ".mov": "Video",
    ".avi": "Video",
    ".mkv": "Video",
    ".webm": "Video",
    ".flv": "Video",
    ".wmv": "Video",
    ".m4a": "Audio",
    ".flac": "Audio",
    ".ogg": "Audio",
    ".opus": "Audio",
    ".wma": "Audio",
    ".aac": "Audio",
    ".aiff": "Audio",
    ".ape": "Audio",
    ".alac": "Audio",
}
